# Project Governance

## Overview
This project is maintained by the teaching staff of the Universitat Rovira i Virgili (URV) for the Computers subject.

## Roles

### Maintainers
Maintainers have write access to the repository. They are responsible for:
* Reviewing and merging Pull Requests.
* Managing releases.
* Enforcing the Code of Conduct.

### Contributors
Contributors are community members who submit issues and Pull Requests. Anyone can be a contributor.

## Decision Making
Decisions are made by consensus among the maintainers. Major changes should be discussed in an issue before implementation.
